"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FetchManager = void 0;
/**
 * Class that controls Moderation Fetch System
 *
 * @class
 * @classdesc Moderator Fetch Manager Class
 */
class FetchManager {
    moderator;
    /**
     * @constructor
     *
     * @param {Moderator} moderator Moderator Class
     */
    constructor(moderator) {
        /**
         * Moderator Class
         *
         * @type {Moderator}
         * @private
         */
        this.moderator = moderator;
    }
    /**
     * Method for obtaining a Discord Guild
     *
     * @param {string} id Discord Guild ID
     *
     * @returns {Promise<Guild>} Discord Guild Object
     */
    guild(id) {
        return new Promise(async (res, rej) => {
            let fetchedGuild = null;
            const cachedGuild = this.moderator.client.guilds.cache.get(id);
            if (!cachedGuild) {
                try {
                    fetchedGuild = await this.moderator.client.guilds.fetch(id);
                }
                catch (error) {
                    return res(null);
                }
                return res(fetchedGuild);
            }
            else
                return res(cachedGuild);
        });
    }
    /**
     * Method for obtaining a Discord channel
     *
     * @param {string} id Discord Channel ID
     *
     * @returns {Promise<Channel>} Discord Channel Object
     */
    channel(id) {
        return new Promise(async (res, rej) => {
            let fetchedChannel = null;
            const cachedChannel = this.moderator.client.channels.cache.get(id);
            if (!cachedChannel) {
                try {
                    fetchedChannel = await this.moderator.client.channels.fetch(id);
                }
                catch (error) {
                    return res(null);
                }
                return res(fetchedChannel);
            }
            else
                return res(cachedChannel);
        });
    }
    /**
     * Method for obtaining a Discord Guild role
     *
     * @param {string} guildID Discord Guild ID
     * @param {string} id Discord Guild Role ID
     *
     * @returns {Promise<Role>} Discord Guild Role Object
     */
    role(guildID, id) {
        return new Promise(async (res, rej) => {
            const guild = await this.guild(guildID);
            if (!guild)
                return res(null);
            let fetchedRole = null;
            const cachedRole = guild.roles.cache.get(id);
            if (!cachedRole) {
                try {
                    fetchedRole = await guild.roles.fetch(id);
                }
                catch (error) {
                    return res(null);
                }
                return res(fetchedRole);
            }
            else
                return res(cachedRole);
        });
    }
    /**
     * Method for getting a Discord Guild user
     *
     * @param {string} guildID Discord Guild ID
     * @param {string} id Discord Guild Member ID
     *
     * @returns {Promise<GuildMember>} Discord Guild Member Object
     */
    member(guildID, id) {
        return new Promise(async (res, rej) => {
            const guild = await this.guild(guildID);
            if (!guild)
                return res(null);
            let fetchedMember = null;
            const cachedMember = guild.members.cache.get(id);
            if (!cachedMember) {
                try {
                    fetchedMember = await guild.members.fetch(id);
                }
                catch (error) {
                    return res(null);
                }
                return res(fetchedMember);
            }
            else
                return res(cachedMember);
        });
    }
}
exports.FetchManager = FetchManager;
